@@ -6,14 +6,15 @@
  *
  *******************************************************************************/
 
-#ifndef THREADINGCACHE_H
-#define THREADINGCACHE_H
+#pragma once
 
-#include <QHash>
 #include "messageitem.h"
+#include <QHash>
 
-namespace MessageList {
-namespace Core {
+namespace MessageList
+{
+namespace Core
+{
 class Aggregation;
 
 class ThreadingCache
@@ -22,7 +23,7 @@ public:
     ThreadingCache();
     ~ThreadingCache();
 
-    bool isEnabled() const;
+    Q_REQUIRED_RESULT bool isEnabled() const;
     void setEnabled(bool enabled);
 
     void load(const QString &id, const Aggregation *aggregation);
@@ -37,18 +38,14 @@ public:
     void expireParent(MessageItem *item);
 
 private:
-    QString cacheFilePath(const QString &id) const;
-
     QHash<qint64 /* child */, qint64 /* parent */> mParentCache;
     QHash<qint64 /* ID */, MessageItem *> mItemCache;
 
     QString mCacheId;
-    Aggregation::Grouping mGrouping;
-    Aggregation::Threading mThreading;
-    Aggregation::ThreadLeader mThreadLeader;
-    bool mEnabled;
+    Aggregation::Grouping mGrouping = Aggregation::NoGrouping;
+    Aggregation::Threading mThreading = Aggregation::NoThreading;
+    Aggregation::ThreadLeader mThreadLeader = Aggregation::TopmostMessage;
+    bool mEnabled = true;
 };
 } // namespace Core
 } // namespace MessageList
-
-#endif
